@@ -1,10 +1,14 @@
+use futures::FutureExt;
+use std::future::Future;
+use std::pin::Pin;
+
 use futuresdr::anyhow::Result;
 use futuresdr::async_trait::async_trait;
-use futuresdr::runtime::AsyncKernel;
 use futuresdr::runtime::Block;
 use futuresdr::runtime::BlockMeta;
 use futuresdr::runtime::BlockMetaBuilder;
 use futuresdr::runtime::Flowgraph;
+use futuresdr::runtime::Kernel;
 use futuresdr::runtime::MessageIo;
 use futuresdr::runtime::MessageIoBuilder;
 use futuresdr::runtime::Pmt;
@@ -27,27 +31,30 @@ pub struct CtrlPortDemo {
 impl CtrlPortDemo {
     #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Block {
-        Block::new_async(
+        Block::new(
             BlockMetaBuilder::new("CtrlPortDemo").build(),
             StreamIoBuilder::new().build(),
             MessageIoBuilder::new()
                 .add_output("out")
-                .add_sync_input("in", Self::handler)
+                .add_input("in", Self::handler)
                 .build(),
             Self { counter: 5 },
         )
     }
 
-    fn handler(
-        &mut self,
-        _mio: &mut MessageIo<CtrlPortDemo>,
-        _meta: &mut BlockMeta,
+    fn handler<'a>(
+        &'a mut self,
+        _mio: &'a mut MessageIo<Self>,
+        _meta: &'a mut BlockMeta,
         _p: Pmt,
-    ) -> Result<Pmt> {
-        self.counter += 1;
-        Ok(Pmt::U64(self.counter - 1))
+    ) -> Pin<Box<dyn Future<Output = Result<Pmt>> + Send + 'a>> {
+        async move {
+            self.counter += 1;
+            Ok(Pmt::U64(self.counter - 1))
+        }
+        .boxed()
     }
 }
 
 #[async_trait]
-impl AsyncKernel for CtrlPortDemo {}
+impl Kernel for CtrlPortDemo {}
