@@ -19,7 +19,7 @@ fn main() {
     println!("FutureSDR Config: {:?}", c);
 
     if let Some(v) = config::get_value("my") {
-        if let Ok(v) = v.try_into::<MyConfig>() {
+        if let Ok(v) = v.try_deserialize::<MyConfig>() {
             println!("MyConfig: {:?}", &v);
         } else {
             println!("MyConfig could not be deserialized");
