@@ -1,8 +1,8 @@
 use crate::anyhow::Result;
-use crate::runtime::AsyncKernel;
 use crate::runtime::Block;
 use crate::runtime::BlockMeta;
 use crate::runtime::BlockMetaBuilder;
+use crate::runtime::Kernel;
 use crate::runtime::MessageIo;
 use crate::runtime::MessageIoBuilder;
 use crate::runtime::StreamIo;
@@ -16,7 +16,7 @@ pub struct ConsoleSink<T: Send + 'static + std::fmt::Debug> {
 
 impl<T: Send + 'static + std::fmt::Debug> ConsoleSink<T> {
     pub fn new(sep: impl Into<String>) -> Block {
-        Block::new_async(
+        Block::new(
             BlockMetaBuilder::new("ConsoleSink").build(),
             StreamIoBuilder::new()
                 .add_input("in", std::mem::size_of::<T>())
@@ -31,7 +31,7 @@ impl<T: Send + 'static + std::fmt::Debug> ConsoleSink<T> {
 }
 
 #[async_trait]
-impl<T: Send + 'static + std::fmt::Debug> AsyncKernel for ConsoleSink<T> {
+impl<T: Send + 'static + std::fmt::Debug> Kernel for ConsoleSink<T> {
     async fn work(
         &mut self,
         io: &mut WorkIo,
