@@ -2,10 +2,10 @@ use std::cmp;
 use std::ptr;
 
 use crate::anyhow::Result;
-use crate::runtime::AsyncKernel;
 use crate::runtime::Block;
 use crate::runtime::BlockMeta;
 use crate::runtime::BlockMetaBuilder;
+use crate::runtime::Kernel;
 use crate::runtime::MessageIo;
 use crate::runtime::MessageIoBuilder;
 use crate::runtime::StreamIo;
@@ -18,7 +18,7 @@ pub struct Copy<T: Send + 'static> {
 
 impl<T: Send + 'static> Copy<T> {
     pub fn new() -> Block {
-        Block::new_async(
+        Block::new(
             BlockMetaBuilder::new("Copy").build(),
             StreamIoBuilder::new()
                 .add_input("in", std::mem::size_of::<T>())
@@ -33,7 +33,7 @@ impl<T: Send + 'static> Copy<T> {
 }
 
 #[async_trait]
-impl<T: Send + 'static> AsyncKernel for Copy<T> {
+impl<T: Send + 'static> Kernel for Copy<T> {
     async fn work(
         &mut self,
         io: &mut WorkIo,
