@@ -2,10 +2,10 @@ use lttng_ust::import_tracepoints;
 use std::ptr;
 
 use crate::anyhow::Result;
-use crate::runtime::AsyncKernel;
 use crate::runtime::Block;
 use crate::runtime::BlockMeta;
 use crate::runtime::BlockMetaBuilder;
+use crate::runtime::Kernel;
 use crate::runtime::MessageIo;
 use crate::runtime::MessageIoBuilder;
 use crate::runtime::StreamIo;
@@ -24,7 +24,7 @@ pub struct NullSource<T: Send + 'static> {
 impl<T: Send + 'static> NullSource<T> {
     #[allow(clippy::new_ret_no_self)]
     pub fn new(probe_granularity: u64) -> Block {
-        Block::new_async(
+        Block::new(
             BlockMetaBuilder::new("LTTngNullSource").build(),
             StreamIoBuilder::new()
                 .add_output("out", std::mem::size_of::<T>())
@@ -41,7 +41,7 @@ impl<T: Send + 'static> NullSource<T> {
 }
 
 #[async_trait]
-impl<T: Send + 'static> AsyncKernel for NullSource<T> {
+impl<T: Send + 'static> Kernel for NullSource<T> {
     async fn init(
         &mut self,
         _sio: &mut StreamIo,
