@@ -12,6 +12,7 @@ use crate::runtime::buffer::BufferReaderCustom;
 use crate::runtime::buffer::BufferWriter;
 use crate::runtime::buffer::BufferWriterHost;
 use crate::runtime::AsyncMessage;
+use crate::runtime::ItemTag;
 
 #[derive(Debug, PartialEq, Hash)]
 pub struct H2D;
@@ -138,7 +139,7 @@ impl BufferWriterHost for WriterH2D {
         }
     }
 
-    fn produce(&mut self, amount: usize) {
+    fn produce(&mut self, amount: usize, _tags: Vec<ItemTag>) {
         // debug!("H2D writer called produce {}", amount);
         let buffer = self.buffer.as_mut().unwrap();
         let capacity = buffer.buffer.buffer.size() as usize / self.item_size;
