@@ -3,6 +3,7 @@ use async_io::block_on;
 #[cfg(not(target_arch = "wasm32"))]
 use async_task::Task;
 use futures::channel::mpsc::{channel, Receiver, Sender};
+use futures::channel::oneshot;
 use futures::future::join_all;
 use futures::future::Either;
 use futures::prelude::*;
@@ -107,12 +108,15 @@ impl<S: Scheduler> Runtime<S> {
         let queue_size = config::config().queue_size;
         let (fg_inbox, fg_inbox_rx) = channel::<AsyncMessage>(queue_size);
 
+        let (tx, rx) = oneshot::channel::<()>();
         let task = self.scheduler.spawn(run_flowgraph(
             fg,
             self.scheduler.clone(),
             fg_inbox.clone(),
             fg_inbox_rx,
+            tx,
         ));
+        block_on(rx).expect("run_flowgraph did not signal startup completed");
         (task, FlowgraphHandle::new(fg_inbox))
     }
 
@@ -147,6 +151,7 @@ async fn run_flowgraph<S: Scheduler>(
     scheduler: S,
     mut main_channel: Sender<AsyncMessage>,
     mut main_rx: Receiver<AsyncMessage>,
+    initialized: oneshot::Sender<()>,
 ) -> Result<Flowgraph> {
     debug!("in run_flowgraph");
     let mut topology = fg.topology.take().context("flowgraph not initialized")?;
@@ -244,7 +249,7 @@ async fn run_flowgraph<S: Scheduler>(
         }
     }
 
-    for m in queue.drain(..) {
+    for m in queue.into_iter() {
         main_channel
             .try_send(m)
             .expect("main inbox exceeded capacity during startup");
@@ -254,6 +259,10 @@ async fn run_flowgraph<S: Scheduler>(
     #[cfg(not(target_arch = "wasm32"))]
     ctrl_port::start_control_port(inboxes.clone()).await;
 
+    initialized
+        .send(())
+        .expect("failed to signal flowgraph startup complete.");
+
     // main loop
     loop {
         if active_blocks == 0 {
@@ -360,20 +369,10 @@ pub(crate) async fn run_block(
                     work_io.finished = true;
                 }
                 Some(Some(AsyncMessage::Call { port_id, data })) => {
-                    if block.message_input_is_async(port_id) {
-                        block.call_async_handler(port_id, data).await?;
-                    } else {
-                        block.call_sync_handler(port_id, data)?;
-                    }
+                    block.call_handler(port_id, data).await?;
                 }
                 Some(Some(AsyncMessage::Callback { port_id, data, tx })) => {
-                    let res = {
-                        if block.message_input_is_async(port_id) {
-                            block.call_async_handler(port_id, data).await?
-                        } else {
-                            block.call_sync_handler(port_id, data)?
-                        }
-                    };
+                    let res = { block.call_handler(port_id, data).await? };
 
                     tx.send(res).unwrap();
                 }
@@ -445,10 +444,8 @@ pub(crate) async fn run_block(
 
         // ================== work
         work_io.call_again = false;
-        match &mut block {
-            Block::Sync(b) => b.work(&mut work_io)?,
-            Block::Async(b) => b.work(&mut work_io).await?,
-        }
+        block.work(&mut work_io).await?;
+        block.commit();
 
         futures_lite::future::yield_now().await;
     }
