@@ -30,7 +30,7 @@ fn flowgraph() -> Result<()> {
 
     fg = Runtime::new().run(fg)?;
 
-    let snk = fg.block_async::<VectorSink<f32>>(vect_sink).unwrap();
+    let snk = fg.kernel::<VectorSink<f32>>(vect_sink).unwrap();
     let v = snk.items();
 
     assert_eq!(v.len(), 1_000_000);
@@ -61,7 +61,7 @@ fn fg_rand_vec() -> Result<()> {
 
     fg = Runtime::new().run(fg)?;
 
-    let snk = fg.block_async::<VectorSink<f32>>(snk).unwrap();
+    let snk = fg.kernel::<VectorSink<f32>>(snk).unwrap();
     let v = snk.items();
 
     assert_eq!(v.len(), n_items);
@@ -98,7 +98,7 @@ fn fg_rand_vec_multi_snk() -> Result<()> {
     fg = Runtime::new().run(fg)?;
 
     for s in &snks {
-        let snk = fg.block_async::<VectorSink<f32>>(*s).unwrap();
+        let snk = fg.kernel::<VectorSink<f32>>(*s).unwrap();
         let v = snk.items();
 
         assert_eq!(v.len(), n_items);
